@@ -1,4 +1,5 @@
-from typing import List, Optional
+# type: ignore
+from typing import Optional
 
 from canvas_workflow_kit.protocol import CONTEXT_REPORT, ClinicalQualityMeasure, ProtocolResult
 from canvas_workflow_kit.value_set.v2018 import (
@@ -14,42 +15,32 @@ from canvas_workflow_kit.value_set.value_set import ValueSet
 
 class DiabetesQualityMeasure(ClinicalQualityMeasure):
 
-    title = 'Diabetes Quality Measure'
-    version = '1.0'
-    changelog = 'Initial release'
+    class Meta:
+        title = 'Diabetes Quality Measure'
+        version = '1.0'
+        changelog = 'Initial release'
 
-    description = f''
-    information = ''
+        description = ''
+        information = ''
 
-    identifiers = []
+        identifiers = []
 
-    types = ['CCP']
+        types = ['CCP']
 
-    responds_to_event_types = [
-    ]
-    authors = [
-        'Canvas Medical Team',
-    ]
+        authors = [
+            'Canvas Medical Team',
+        ]
+
+        abstract = True
 
     AGE_RANGE_START = 18
     AGE_RANGE_END = 75
 
-    class Meta:
-        abstract = True
-
     @classmethod
     def enabled(cls) -> bool:
         # necessary to prevent error based on not implementing the methods
         return True
 
-    @classmethod
-    def revision(cls) -> str:
-        raise NotImplementedError('revision must be overridden')
-
-    @property
-    def references(self) -> List[str]:
-        raise NotImplementedError('revision must be overridden')
-
     def in_initial_population(self) -> bool:
         """
         Initial population: Patients 18-75 years of age with diabetes with a visit during the
