@@ -50,6 +50,9 @@ class CHANGE_TYPE:
     CONDITION = 'condition'
     "Recompute protocol when a patient's condition is updated."
 
+    CONSENT = 'consent'
+    "Recompute protocol when a patient's consents are updated"
+
     COVERAGE = 'coverage'
     "Recompute protocol when a patient's insurance coverage is updated."
 
@@ -95,6 +98,9 @@ class CHANGE_TYPE:
     SUSPECT_HCC = 'suspect_hcc'
     "Recompute protocol when hierarchical condition categories are updated."
 
+    TASK = 'task'
+    "Recompute protocol when a task related to the patient is updated"
+
     VITAL_SIGN = 'vital_sign'
     "Recompute protocol when a patient's vital signs are updated."
 
