@@ -3,7 +3,7 @@ from typing import Any, Dict
 def ensure_patient_in_group(patient_key: str, group_externally_exposable_id: str) -> Dict[str, Any]:
     
     return {
-        'integration_type': 'PatientGroup',
+        'integration_type': 'Group',
         'integration_source': 'SDK',
         'handling_options': {
             'respond_async': True
@@ -22,7 +22,7 @@ def ensure_patient_in_group(patient_key: str, group_externally_exposable_id: str
 
 def ensure_patient_not_in_group(patient_key: str, group_externally_exposable_id: str) -> str:
     return {
-        'integration_type': 'PatientGroup',
+        'integration_type': 'Group',
         'integration_source': 'SDK',
         'handling_options': {
             'respond_async': True
