@@ -22,6 +22,7 @@ class TestPatient(SDKBaseTest):
         self.assertFalse(tested.active_only)
         self.assertEqual('empty', tested.patient_key)
         fields = [
+            'appointments',
             'billing_line_items',
             'conditions',
             'consents',
@@ -49,6 +50,7 @@ class TestPatient(SDKBaseTest):
         self.assertEqual('partial', tested.patient_key)
 
         fields = {
+            'appointments': 1,
             'billing_line_items': 0,
             'conditions': 2,
             'consents': 1,
@@ -79,6 +81,7 @@ class TestPatient(SDKBaseTest):
         self.assertFalse(tested.active_only)
         self.assertEqual('full', tested.patient_key)
         fields = {
+            'appointments': 4,
             'billing_line_items': 2,
             'conditions': 3,
             'consents': 2,
@@ -107,6 +110,7 @@ class TestPatient(SDKBaseTest):
     def test_recordset_classes(self):
         tested = self.load_patient('full')
         expected = [
+            'AppointmentRecordSet',
             'AdministrativeDocumentRecordSet',
             'AllergyIntoleranceRecordSet',
             'BillingLineItemRecordSet',
@@ -143,6 +147,7 @@ class TestPatient(SDKBaseTest):
         expected = [
             'administrative_documents',
             'allergy_intolerances',
+            'appointments',
             'billing_line_items',
             'conditions',
             'consents',
@@ -350,6 +355,7 @@ class TestPatient(SDKBaseTest):
 
     def test_as_dict(self):
         fields = [
+            'appointments',
             'administrative_documents',
             'allergy_intolerances',
             'billing_line_items',
